@@ -12,7 +12,7 @@ import datetime
 # Suppose separate build and source structure and logo.png in _static folder
 
 # Settings
-PROJECT = "mypythontools"
+PROJECT = {{}}
 AUTHOR = "Daniel Malachov"
 GITHUB_USER = "Malachov"
 
@@ -28,6 +28,7 @@ for i in [script_dir, root, lib_path]:
     if i.as_posix() not in sys.path:
         sys.path.insert(0, i.as_posix())
 
+
 # -- Project information -----------------------------------------------------
 
 copyright = f"2020, {AUTHOR}"  # pylint: disable=redefined-builtin
@@ -83,7 +84,7 @@ html_static_path = ["_static"]
 # html_extra_path = ['../extra']
 
 html_css_files = [
-    "https://malachov.github.io/mypythontools/content/sphinx-alabaster-css/custom.css",
+    "https://malachov.github.io/mypythontools/tools/sphinx-alabaster-css/custom.css",
 ]
 
 napoleon_custom_sections = [
