@@ -28,23 +28,14 @@
     :target: https://codecov.io/gh/Malachov/mypythontools
     :alt: Codecov
 
-It's called mypythontools, but it's also made for you...
 
-Can be used as python library. Things like building the application with pyinstaller, incrementing version,
-generating rst files for sphinx docs, pushing to GitHub or deploying to PyPi or other CI/CD functionality,
-creating config module or plot data is the matter of calling one function or clicking one button (e.g. VS Code
-task).
+It's called mypythontools, but it's also made for you...
 
 Many projects - one codebase.
 
-If you are not sure whether the structure of your app will work with this code, check `project-starter` on
-GitHub in `Tools` folder.
+There is also some extra stuff, that is not bundled via PyPI (CSS for readthedocs etc.),
+such a content is under the `Tools` topic.
 
-Paths are inferred, but if you have atypical structure or have more projects in cwd, setup necessary paths in
-paths module.
-
-There is also some extra stuff, that is not bundled via PyPI (cookiecutter, CSS for readthedocs etc.), such a
-content is under the `Tools` topic.
 
 Links
 =====
@@ -226,37 +217,13 @@ Result should look like this
     :width: 620
     :alt: sphinx-alabaster-css
     :align: center
-
-Tasks
------
-
-There are VS Code tasks examples in utils and build module, but here is small tutorial how to use it. Run
-command `Tasks: Open User Tasks`, add tasks from github/content/tasks or if you have no task yet, you can
-copy / paste all.
-
-Install extension **Task Explorer**
-
-On root copy folder `utils` from tools/tasks
-
-You are ready to go. You should see something like this
-
-.. image:: /_static/tasks.png
-    :width: 620
-    :alt: tasks
-    :align: center
-
-You can do CI / CD pipeline or Build app with one click now.
 """
-import mylogging as __mylogging
+from mypythontools import config, misc, paths, plots, property, system, types
 
-from mypythontools import config, misc, paths, plots, property, terminal, types
+__all__ = ["config", "misc", "paths", "plots", "property", "system", "types"]
 
-__all__ = ["config", "misc", "paths", "plots", "property", "terminal", "types"]
-
-__version__ = "1.0.1"
+__version__ = "1.0.5"
 
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
 __email__ = "malachovd@seznam.cz"
-
-__mylogging.my_traceback.enhance_excepthook()
